pub struct P2pConfig {
pub listen_address: SocketAddr,
pub external_address: Option<Multiaddr>,
pub seed_peers: Vec<SeedPeer>,
pub peer_address_overrides: Vec<PeerAddresses>,
pub anemo_config: Option<Config>,
pub state_sync: Option<StateSyncConfig>,
pub discovery: Option<DiscoveryConfig>,
pub randomness: Option<RandomnessConfig>,
pub excessive_message_size: Option<usize>,
}Fields
listen_address: SocketAddrThe address that the p2p network will bind on.
external_address: Option<Multiaddr>The external address other nodes can use to reach this node. This will be shared with other peers through the discovery service
seed_peers: Vec<SeedPeer>SeedPeers are preferred and the node will always try to ensure a connection is established with these nodes.
peer_address_overrides: Vec<PeerAddresses>Manually configured peer addresses. These override addresses loaded from on-chain configs.
anemo_config: Option<Config>state_sync: Option<StateSyncConfig>discovery: Option<DiscoveryConfig>randomness: Option<RandomnessConfig>excessive_message_size: Option<usize>Size in bytes above which network messages are considered excessively large. Excessively large messages will still be handled, but logged and reported in metrics for debugging.
If unspecified, this will default to 8 MiB.
Implementations
Sourceimpl P2pConfig
impl P2pConfig
pub fn excessive_message_size(&self) -> usize
pub fn set_discovery_config(self, discovery_config: DiscoveryConfig) -> Self