pub struct StateSyncConfig {Show 25 fields
pub pinned_checkpoints: Vec<(CheckpointSequenceNumber, CheckpointDigest)>,
pub interval_period_ms: Option<u64>,
pub mailbox_capacity: Option<usize>,
pub synced_checkpoint_broadcast_channel_capacity: Option<usize>,
pub checkpoint_header_download_concurrency: Option<usize>,
pub checkpoint_content_download_concurrency: Option<usize>,
pub checkpoint_content_download_tx_concurrency: Option<u64>,
pub timeout_ms: Option<u64>,
pub checkpoint_content_timeout_ms: Option<u64>,
pub push_checkpoint_summary_rate_limit: Option<NonZeroU32>,
pub get_checkpoint_summary_rate_limit: Option<NonZeroU32>,
pub get_checkpoint_contents_rate_limit: Option<NonZeroU32>,
pub get_checkpoint_contents_inflight_limit: Option<usize>,
pub get_checkpoint_contents_per_checkpoint_limit: Option<usize>,
pub wait_interval_when_no_peer_to_sync_content_ms: Option<u64>,
pub use_get_checkpoint_contents_v2: Option<bool>,
pub max_checkpoint_lookahead: Option<u64>,
pub max_checkpoint_sync_batch_size: Option<u64>,
pub max_checkpoint_summary_size: Option<usize>,
pub checkpoint_content_timeout_min_ms: Option<u64>,
pub checkpoint_content_timeout_max_ms: Option<u64>,
pub peer_scoring_window_ms: Option<u64>,
pub exploration_probability: Option<f64>,
pub peer_failure_rate: Option<f64>,
pub peer_disconnect_threshold_ms: Option<u64>,
}Fields
pinned_checkpoints: Vec<(CheckpointSequenceNumber, CheckpointDigest)>List of “known-good” checkpoints that state sync will be forced to use. State sync will skip verification of pinned checkpoints, and reject checkpoints with digests that don’t match pinned values for a given sequence number.
This can be used:
- in case of a fork, to prevent the node from syncing to the wrong chain.
- in case of a network stall, to force the node to proceed with a manually-injected checkpoint.
interval_period_ms: Option<u64>Query peers for their latest checkpoint every interval period.
If unspecified, this will default to 5,000 milliseconds.
mailbox_capacity: Option<usize>Size of the StateSync actor’s mailbox.
If unspecified, this will default to 1,024.
synced_checkpoint_broadcast_channel_capacity: Option<usize>Size of the broadcast channel use for notifying other systems of newly sync’ed checkpoints.
If unspecified, this will default to 1,024.
checkpoint_header_download_concurrency: Option<usize>Set the upper bound on the number of checkpoint headers to be downloaded concurrently.
If unspecified, this will default to 400.
checkpoint_content_download_concurrency: Option<usize>Set the upper bound on the number of checkpoint contents to be downloaded concurrently.
If unspecified, this will default to 400.
checkpoint_content_download_tx_concurrency: Option<u64>Set the upper bound on the number of individual transactions contained in checkpoint
contents to be downloaded concurrently. If both this value and
checkpoint_content_download_concurrency are set, the lower of the two will apply.
If unspecified, this will default to 50,000.
timeout_ms: Option<u64>Set the timeout that should be used when sending most state-sync RPC requests.
If unspecified, this will default to 10,000 milliseconds.
checkpoint_content_timeout_ms: Option<u64>Set the timeout that should be used when sending RPC requests to sync checkpoint contents.
If unspecified, this will default to 10,000 milliseconds.
push_checkpoint_summary_rate_limit: Option<NonZeroU32>Per-peer rate-limit (in requests/sec) for the PushCheckpointSummary RPC.
If unspecified, this will default to no limit.
get_checkpoint_summary_rate_limit: Option<NonZeroU32>Per-peer rate-limit (in requests/sec) for the GetCheckpointSummary RPC.
If unspecified, this will default to no limit.
get_checkpoint_contents_rate_limit: Option<NonZeroU32>Per-peer rate-limit (in requests/sec) for the GetCheckpointContents RPC.
If unspecified, this will default to no limit.
get_checkpoint_contents_inflight_limit: Option<usize>Per-peer inflight limit for the GetCheckpointContents RPC.
If unspecified, this will default to no limit.
get_checkpoint_contents_per_checkpoint_limit: Option<usize>Per-checkpoint inflight limit for the GetCheckpointContents RPC. This is enforced globally across all peers.
If unspecified, this will default to no limit.
wait_interval_when_no_peer_to_sync_content_ms: Option<u64>The amount of time to wait before retry if there are no peers to sync content from. If unspecified, this will set to default value
use_get_checkpoint_contents_v2: Option<bool>If true, the v2 version of get_checkpoint_contents will be used.
If unspecified, this will default to true.
max_checkpoint_lookahead: Option<u64>Maximum lookahead (in checkpoint sequence numbers) for storing unverified checkpoint summaries received via PushCheckpointSummary.
If unspecified, this will default to 1,000.
max_checkpoint_sync_batch_size: Option<u64>Maximum number of checkpoint headers to attempt to sync in a single sync task.
If unspecified, this will default to 400.
max_checkpoint_summary_size: Option<usize>Maximum serialized size in bytes for a CertifiedCheckpointSummary received via PushCheckpointSummary.
If unspecified, this will default to 262,144 (256 KiB).
checkpoint_content_timeout_min_ms: Option<u64>Minimum timeout for checkpoint content downloads (adaptive timeout lower bound).
If unspecified, this will default to 10,000 milliseconds.
checkpoint_content_timeout_max_ms: Option<u64>Maximum timeout for checkpoint content downloads (adaptive timeout upper bound).
If unspecified, this will default to 30,000 milliseconds.
peer_scoring_window_ms: Option<u64>Time window for peer scoring samples.
If unspecified, this will default to 60,000 milliseconds.
exploration_probability: Option<f64>Probability of selecting an unknown peer to explore its throughput.
If unspecified, this will default to 0.1.
peer_failure_rate: Option<f64>Failure rate threshold for marking a peer as failing. A peer is marked as failing if its failure rate exceeds this threshold.
If unspecified, this will default to 0.3 (30%).
peer_disconnect_threshold_ms: Option<u64>Duration in milliseconds that a peer must be continuously failing before it is reported to discovery for disconnection. Set to 0 to disable automatic reporting of failing peers.
If unspecified, this will default to 30,000 (30 seconds).
Implementations
Sourceimpl StateSyncConfig
impl StateSyncConfig
pub fn interval_period(&self) -> Duration
pub fn mailbox_capacity(&self) -> usize
pub fn synced_checkpoint_broadcast_channel_capacity(&self) -> usize
pub fn checkpoint_header_download_concurrency(&self) -> usize
pub fn checkpoint_content_download_concurrency(&self) -> usize
pub fn checkpoint_content_download_tx_concurrency(&self) -> u64
pub fn timeout(&self) -> Duration
pub fn checkpoint_content_timeout(&self) -> Duration
pub fn wait_interval_when_no_peer_to_sync_content(&self) -> Duration
pub fn use_get_checkpoint_contents_v2(&self) -> bool
pub fn max_checkpoint_lookahead(&self) -> u64
pub fn max_checkpoint_sync_batch_size(&self) -> u64
pub fn max_checkpoint_summary_size(&self) -> usize
pub fn checkpoint_content_timeout_min(&self) -> Duration
pub fn checkpoint_content_timeout_max(&self) -> Duration
pub fn peer_scoring_window(&self) -> Duration
pub fn exploration_probability(&self) -> f64
pub fn peer_failure_rate(&self) -> f64
pub fn peer_disconnect_threshold(&self) -> Duration
pub fn randomized_for_testing() -> Self